unit ResourceCompUnit;
{reSource Component Unit
Component Front End for reSource Compression Engine

  reSource version 2.5 BETA
  Copyright (C) 1998-2000 Victor Kasenda / gruv
  http://gruv.tripod.com/resource/
  email: gruv@bigfoot.com

  
  USAGE:
  Drop the component onto the form to use it.
  Default name will be Resource1.
  To perform any action on the archive, use Resource1.ArchiveMan (Archive Manager)

  ACTIONS:
  Before doing any action, set the parameters for ArchiveMan
    Resource1.ArchiveMan.TempDir := 'c:\temp';

  To Open an Archive:
    Resource1.ArchiveMan.OpenArchive(<ArchiveName>);

  To Close the Archive:
    Resource1.ArchiveMan.CloseArchive;

  To Add files:
    Resource1.ArchiveMan.AddFiles(FileList: TStrings; const infile_dir: string)
    There are 2 ways to send the FileList
      - If each entry in FileList has the full Path+Name, then infile_dir can be ''.
      - If each entry in FileList is only the name, then infile_dir must contain
        the path the files are in.

  To Extract the file:
    Before calling ExtractList, set the parameters for file extract:
      Resource1.ArchiveMan.dest_dir := 'c:\mydir'; // destination dir for extract
      
    Resource1.ArchiveMan.ExtractList(List: TList; var files_extracted, extracted_size: integer);

    List is a TList of TCentralFileHeader.
    The CentralFileHeader is gotten from Resource1.ArchiveMan.ArchiveFile.CentralDir[i],
    where i is the index of the file.
    So to add file index 2 to the extract list, call
    List.Add(Resource1.ArchiveMan.ArchiveFile.CentralDir[2]);
    Then call ExtractList(List, a, b)
    The files_extracted and extracted_size are returned values.

  To Delete files:
    Resource1.ArchiveMan.DeleteFiles
    All files that are flagged for deletion are removed.
    To flag a file for delete, set the Delete property in its CentralFileHeader entry.
    e.g. to delete file of index 2 and 5,
      Resource1.ArchiveMan.ArchiveFile.CentralDir[2].Deleted := true; // flag
      Resource1.ArchiveMan.ArchiveFile.CentralDir[5].Deleted := true; // flag
      Resource1.ArchiveMan.DeleteFiles;                               // actual process


      
  EVENTS:
  OnCentralDirChange
    - called when Resource1.ArchiveMan.ArchiveFile.CentralDir changes.
      use it to update the list of files in the archive.
  OnAddLog (for debugging)
    - called when ArchiveMan outputs verbose information on what it is doing.
      mainly used for debugging.
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  {CG}
  ArchiveManagerUnit, StructsUnit;

type
  TResource = class(TComponent)
  private
    {function GetOnShowStatusMsg: TStrEvent;
    procedure SetOnShowStatusMsg(const Value: TStrEvent);}
    function GetOnCentralDirChange: TNotifyEvent;
    procedure SetOnCentralDirChange(const Value: TNotifyEvent);
    function GetOnAddLog: TStrEvent;
    procedure SetOnAddLog(const Value: TStrEvent);
  protected
    FArchiveMan: TArchiveManager;
  public
    property ArchiveMan: TArchiveManager read FArchiveMan;
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property OnCentralDirChange: TNotifyEvent read GetOnCentralDirChange write SetOnCentralDirChange;
    //property OnShowStatusMsg: TStrEvent read GetOnShowStatusMsg write SetOnShowStatusMsg;
    property OnAddLog: TStrEvent read GetOnAddLog write SetOnAddLog;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Compression', [TResource]);
end;


{ TResource }

constructor TResource.Create(AOwner: TComponent);
begin
  inherited;
  {if not (csDesigning in ComponentState) then
  begin}
    FArchiveMan := TArchiveManager.Create;
  {end;}
end;


destructor TResource.Destroy;
begin
  if Assigned(FArchiveMan) then FArchiveMan.Free;
  inherited;
end;

function TResource.GetOnAddLog: TStrEvent;
begin
  result := FArchiveMan.OnAddLog;
end;

function TResource.GetOnCentralDirChange: TNotifyEvent;
begin
  result := FArchiveMan.OnCentralDirChange;
end;

{function TResource.GetOnShowStatusMsg: TStrEvent;
begin
  result := FArchiveMan.OnShowStatusMsg;
end;}

procedure TResource.SetOnAddLog(const Value: TStrEvent);
begin
  FArchiveMan.OnAddLog := Value;
end;

procedure TResource.SetOnCentralDirChange(const Value: TNotifyEvent);
begin
  FArchiveMan.OnCentralDirChange := Value;
end;

{procedure TResource.SetOnShowStatusMsg(const Value: TStrEvent);
begin
  FArchiveMan.OnShowStatusMsg := Value;
end;}

end.
